@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: buildhash.c,v 1.60 1994/01/25 07:11:18 geoff Exp $";
+    "$Id: buildhash.c,v 1.63 1994/10/26 05:12:25 geoff Exp $";
 #endif
 
 #define MAIN
@@ -49,6 +49,15 @@ static char Rcs_Id[] =
 
 /*
  * $Log: buildhash.c,v $
+ * Revision 1.63  1994/10/26  05:12:25  geoff
+ * Get rid of some duplicate declarations.
+ *
+ * Revision 1.62  1994/07/28  05:11:33  geoff
+ * Log message for previous revision: distinguish a zero count from a bad
+ * count file.
+ *
+ * Revision 1.61  1994/07/28  04:53:30  geoff
+ *
  * Revision 1.60  1994/01/25  07:11:18  geoff
  * Get rid of all old RCS log lines in preparation for the 3.1 release.
  *
@@ -77,11 +86,6 @@ static void	newcount P ((void));
 struct stat	dstat;		/* Result of stat-ing dict file */
 struct stat	cstat;		/* Result of stat-ing count file */
 
-int		hashsize;	/* Number of entries to go in hash table */
-
-struct hashheader hashheader;	/* Header of hash table being built */
-struct dent *	hashtbl;	/* Entries to go in hash table */
-
 char *		Dfile;		/* Name of dictionary file */
 char *		Hfile;		/* Name of hash (output) file */
 char *		Lfile;		/* Name of language file */
@@ -148,13 +152,16 @@ int main (argc, argv)
 	exit (1);
 	}
     hashsize = 0;
-    (void) fscanf (countf, "%d", &hashsize);
-    (void) fclose (countf);
-    if (hashsize == 0)
+    if (fscanf (countf, "%d", &hashsize) != 1  ||  fclose (countf) == EOF)
 	{
 	(void) fprintf (stderr, BHASH_C_BAD_COUNT);
 	exit (1);
 	}
+    if (hashsize == 0)
+	{
+	(void) fprintf (stderr, BHASH_C_ZERO_COUNT);
+	exit (1);
+	}
     readdict ();
 
     if ((statf = fopen (Sfile, "w")) == NULL)
