@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: defmt.c,v 1.31 1994/05/25 04:29:28 geoff Exp $";
+    "$Id: defmt.c,v 1.36 1994/10/25 05:46:34 geoff Exp $";
 #endif
 
 /*
@@ -54,6 +54,28 @@ static char Rcs_Id[] =
 
 /*
  * $Log: defmt.c,v $
+ * Revision 1.36  1994/10/25  05:46:34  geoff
+ * Recognize a few more Latex commands: pagestyle, pagenumbering,
+ * setcounter, addtocounter, setlength, addtolength, settowidth.
+ *
+ * Revision 1.35  1994/10/18  04:03:19  geoff
+ * Add code to skip hex numbers if they're preceded by '0x'.
+ *
+ * Revision 1.34  1994/10/04  03:51:24  geoff
+ * Modify the parsing so that TeX commands are ignored even within
+ * comments, but do not affect the overall parsing state.  (This is
+ * slightly imperfect, in that some types of modality are ignored when
+ * comments are entered.  But it should solve nearly all the problems
+ * with commented-out TeX commands.)  This also fixes a couple of minor
+ * bugs with TeX deformatting.
+ *
+ * Revision 1.33  1994/10/03  17:06:07  geoff
+ * Remember to use contextoffset when reporting complete misses
+ *
+ * Revision 1.32  1994/08/31  05:58:41  geoff
+ * Report the offset-within-line correctly in -a mode even if the line is
+ * longer than BUFSIZ characters.
+ *
  * Revision 1.31  1994/05/25  04:29:28  geoff
  * If two boundary characters appear in a row, consider it the end of the
  * word.
@@ -104,15 +126,23 @@ static int	TeX_strncmp P ((char * a, char * b, int n));
 			((c) == TEXDOLLAR) || \
 			((c) == TEXPERCENT))
 
+/*
+ * The following variables are used to save the parsing state when
+ * processing comments.  This allows comments to be parsed without
+ * affecting the overall nesting.
+ */
+
+static int save_math_mode;
+static char save_LaTeX_Mode;
+
 static char * skiptoword (bufp)		/* Skip to beginning of a word */
     char *	bufp;
     {
 
     while (*bufp
-      &&  !isstringch(bufp, 0)
-      &&  (!iswordch(chartoichar (*bufp))
-	||  isboundarych(chartoichar (*bufp))
-	||  (tflag  &&  (math_mode & 1)  &&  !TeX_comment))
+      &&  ((!isstringch (bufp, 0)  &&  !iswordch (chartoichar (*bufp)))
+	||  isboundarych (chartoichar (*bufp))
+	||  (tflag  &&  (math_mode & 1)))
       )
 	{
 	/* check paren necessity... */
@@ -121,10 +151,17 @@ static char * skiptoword (bufp)		/* Skip to beginning of a word */
 	    /* Odd numbers mean we are in "math mode" */
 	    /* Even numbers mean we are in LR or */
 	    /* paragraph mode */
-	    if (TeX_comment)
-		;			/* Don't check comments */
-	    else if (*bufp == TEXPERCENT)
-		TeX_comment = 1;
+	    if (*bufp == TEXPERCENT)
+		{
+		if (!TeX_comment)
+		    {
+		    save_math_mode = math_mode;
+		    save_LaTeX_Mode = LaTeX_Mode;
+		    math_mode = 0;
+		    LaTeX_Mode = 'P';
+		    TeX_comment = 1;
+		    }
+		}
 	    else if (math_mode & 1)
 		{
 		if ((LaTeX_Mode == 'e'  &&  TeX_math_check('e', &bufp))
@@ -231,10 +268,30 @@ static char * skiptoword (bufp)		/* Skip to beginning of a word */
 		    }
 		}
 	    }
-	bufp++;
+	/*
+	 * Skip hex numbers, but not if we're in non-terse askmode.
+	 * (In that case, we'd lose sync if we skipped hex.)
+	 */
+	if (*bufp == '0'
+	  &&  (bufp[1] == 'x'  ||  bufp[1] == 'X')
+	  &&  (terse  ||  !aflag))
+	    {
+	    bufp += 2;
+	    while (isxdigit (*bufp))
+		bufp++;
+	    }
+	else
+	    bufp++;
 	}
     if (*bufp == '\0')
-	TeX_comment = 0;
+	{
+	if (TeX_comment)
+	    {
+	    math_mode = save_math_mode;
+	    LaTeX_Mode = save_LaTeX_Mode;
+	    TeX_comment = 0;
+	    }
+	}
     return bufp;
     }
 
@@ -249,7 +306,12 @@ char * skipoverword (bufp)	/* Return pointer to end of a word */
 	{
 	if (*bufp == '\0')
 	    {
-	    TeX_comment = 0;
+	    if (TeX_comment)
+		{
+		math_mode = save_math_mode;
+		LaTeX_Mode = save_LaTeX_Mode;
+		TeX_comment = 0;
+		}
 	    break;
 	    }
 	else if (l_isstringch(bufp, scharlen, 0))
@@ -428,7 +490,7 @@ void checkline (ofile)
 			  ctoken,
 			  easypossibilities,
 			  (int) ((currentchar - contextbufs[0])
-			    - strlen (ctoken)));
+			    - strlen (ctoken)) + contextoffset);
 			for (i = 0;  i < MAXPOSSIBLE;  i++)
 			    {
 			    if (possibilities[i][0] == 0)
@@ -446,7 +508,7 @@ void checkline (ofile)
 			(void) fprintf (ofile, "# %s %d\n",
 			  ctoken,
 			  (int) ((currentchar - contextbufs[0])
-			    - strlen (ctoken)));
+			    - strlen (ctoken)) + contextoffset);
 			}
 		    }
 		}
@@ -470,9 +532,7 @@ static int TeX_math_end (bufp)
     char **	bufp;
     {
 
-    if (TeX_comment)
-	return 0;
-    else if (**bufp == TEXDOLLAR)
+    if (**bufp == TEXDOLLAR)
 	{
 	if ((*bufp)[1] == TEXDOLLAR)
 	    (*bufp)++;
@@ -480,7 +540,14 @@ static int TeX_math_end (bufp)
 	}
     else if (**bufp == TEXPERCENT)
 	{
-	TeX_comment = 1;
+	if (!TeX_comment)
+	    {
+	    save_math_mode = math_mode;
+	    save_LaTeX_Mode = LaTeX_Mode;
+	    math_mode = 0;
+	    LaTeX_Mode = 'P';
+	    TeX_comment = 1;
+	    }
 	return 0;
 	}
     /* processing extended TeX command */
@@ -703,7 +770,6 @@ static void TeX_skip_check (bufp)
     int		charlen;
 
     /* ADDITIONALLY, MAY WANT TO ADD:
-     * input, include, includeonly,
      * documentstyle, pagestyle, pagenumbering
      * WITH TWO {} {}'S TO SKIP:
      * setcounter, addtocounter,
@@ -722,6 +788,8 @@ static void TeX_skip_check (bufp)
       ||  TeX_strncmp(*bufp, "include", 7) == 0
       ||  TeX_strncmp(*bufp, "includeonly", 11) == 0
       ||  TeX_strncmp(*bufp, "documentstyle", 13) == 0
+      ||  TeX_strncmp(*bufp, "pagestyle", 9) == 0
+      ||  TeX_strncmp(*bufp, "pagenumbering", 13) == 0
 #ifndef IGNOREBIB
       ||  TeX_strncmp(*bufp, "bibliography", 12) == 0
       ||  TeX_strncmp(*bufp, "bibitem", 7) == 0
@@ -733,7 +801,12 @@ static void TeX_skip_check (bufp)
 	if (**bufp == 0)
 	    LaTeX_Mode = 'r';
 	}
-    else if (TeX_strncmp(*bufp, "rule", 4) == 0)	/* skip two args. */
+    else if (TeX_strncmp(*bufp, "rule", 4) == 0		/* skip two args. */
+      ||  TeX_strncmp(*bufp, "setcounter", 10) == 0
+      ||  TeX_strncmp(*bufp, "addtocounter", 12) == 0
+      ||  TeX_strncmp(*bufp, "setlength", 9) == 0
+      ||  TeX_strncmp(*bufp, "addtolength", 11) == 0
+      ||  TeX_strncmp(*bufp, "settowidth", 10) == 0)
 	{
 	TeX_skip_parens (bufp);
 	if (**bufp == 0)	/* Only skips one {} if not on same line. */
@@ -766,6 +839,11 @@ static void TeX_skip_check (bufp)
 		break;
 	    *bufp += charlen;
 	    }
+	/*
+	** Our caller expects to skip over a single character.  So we
+	** need to back up by one.  Ugh.
+	*/
+	(*bufp)--;
 	}
     }
 
