@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: ispell.c,v 1.123 1994/05/17 06:44:12 geoff Exp $";
+    "$Id: ispell.c,v 1.128 1994/10/26 05:12:28 geoff Exp $";
 #endif
 
 #define MAIN
@@ -49,6 +49,23 @@ static char Rcs_Id[] =
 
 /*
  * $Log: ispell.c,v $
+ * Revision 1.128  1994/10/26  05:12:28  geoff
+ * Include boundary characters in the list of characters to be tried in
+ * corrections.
+ *
+ * Revision 1.127  1994/10/25  05:46:07  geoff
+ * Allow the default dictionary to be specified by an environment
+ * variable (DICTIONARY) as well as a switch.
+ *
+ * Revision 1.126  1994/09/16  03:32:34  geoff
+ * Issue an error message for bad affix flags
+ *
+ * Revision 1.125  1994/07/28  05:11:36  geoff
+ * Log message for previous revision: fix backup-file checks to correctly
+ * test for exceeding MAXNAMLEN.
+ *
+ * Revision 1.124  1994/07/28  04:53:39  geoff
+ *
  * Revision 1.123  1994/05/17  06:44:12  geoff
  * Add support for controlled compound formation and the COMPOUNDONLY
  * option to affix flags.
@@ -138,6 +155,11 @@ static void initckch (wchars)
 		++Trynum;
 		}
 	    }
+	else if (isboundarych (c))
+	    {
+	    Try[Trynum] = c;
+	    ++Trynum;
+	    }
 	}
     if (wchars != NULL)
 	{
@@ -218,7 +240,19 @@ int main (argc, argv)
 
     Trynum = 0;
 
-    (void) sprintf (hashname, "%s/%s", LIBDIR, DEFHASH);
+    p = getenv ("DICTIONARY");
+    if (p != NULL)
+	{
+	if (index (p, '/') != NULL)
+	    (void) strcpy (hashname, p);
+	else
+	    (void) sprintf (hashname, "%s/%s", LIBDIR, p);
+	p = rindex (p, '.');
+	if (p == NULL  ||  strcmp (p, ".hash") != 0)
+	    (void) strcat (hashname, ".hash");
+	}
+    else
+	(void) sprintf (hashname, "%s/%s", LIBDIR, DEFHASH);
 
     cpd = NULL;
 
@@ -816,8 +850,8 @@ static void update_file (filename, statbuf)
 	pathtail = bakfile;
     else
 	pathtail++;
-    if (strncmp (pathtail, bakfile, MAXNAMLEN) != 0)
-      (void) unlink (bakfile);	/* unlink so we can write a new one. */
+    if (strncmp (filename, bakfile, pathtail - bakfile + MAXNAMLEN) != 0)
+	(void) unlink (bakfile);	/* unlink so we can write a new one. */
     if (link (filename, bakfile) == 0)
 	(void) unlink (filename);
 
@@ -837,7 +871,8 @@ static void update_file (filename, statbuf)
     (void) fclose (infile);
     (void) fclose (outfile);
 
-    if (xflag  &&  strncmp (pathtail, bakfile, MAXNAMLEN) != 0)
+    if (xflag
+      &&  strncmp (filename, bakfile, pathtail - bakfile + MAXNAMLEN) != 0)
 	(void) unlink (bakfile);
     }
 
@@ -887,13 +922,11 @@ static void expandmode (option)
 	    (void) bzero ((char *) mask, sizeof (mask));
 	    while (*flagp != '\0'  &&  *flagp != '\n')
 		{
-#if MASKBITS <= 32
-		temp = CHARTOBIT (mytoupper (chartoichar (*flagp)));
-#else
 		temp = CHARTOBIT ((unsigned char) *flagp);
-#endif
 		if (temp >= 0  &&  temp <= LARGESTFLAG)
 		    SETMASKBIT (mask, temp);
+		else
+		    (void) fprintf (stderr, BAD_FLAG, (unsigned char) *flagp);
 		flagp++;
 		/* Accept old-format dicts with extra slashes */
 		if (*flagp == hashheader.flagmarker)
