@@ -1,5 +1,5 @@
 /*
- * $Id: ispell.h,v 1.60 1994/05/17 06:44:15 geoff Exp $
+ * $Id: ispell.h,v 1.65 1994/11/02 06:56:10 geoff Exp $
  */
 
 /*
@@ -42,6 +42,25 @@
 
 /*
  * $Log: ispell.h,v $
+ * Revision 1.65  1994/11/02  06:56:10  geoff
+ * Remove the anyword feature, which I've decided is a bad idea.
+ *
+ * Revision 1.64  1994/10/25  05:46:18  geoff
+ * Add the FF_ANYWORD flag for defining an affix that will apply to any
+ * word, even if not explicitly specified.  (Good for French.)
+ *
+ * Revision 1.63  1994/09/16  04:48:28  geoff
+ * Make stringdups and laststringch unsigned ints, and dupnos a plain
+ * int, so that we can handle more than 128 stringchars and stringchar
+ * types.
+ *
+ * Revision 1.62  1994/09/01  06:06:39  geoff
+ * Change erasechar/killchar to uerasechar/ukillchar to avoid
+ * shared-library problems on HP systems.
+ *
+ * Revision 1.61  1994/08/31  05:58:35  geoff
+ * Add contextoffset, used in -a mode to handle extremely long lines.
+ *
  * Revision 1.60  1994/05/17  06:44:15  geoff
  * Add support for controlled compound formation and the COMPOUNDONLY
  * option to affix flags.
@@ -328,8 +347,8 @@ struct hashheader
     char boundarychars[SET_SIZE + MAXSTRINGCHARS]; /* NZ for boundary chars */
     char stringstarts[SET_SIZE];		/* NZ if char can start str */
     char stringchars[MAXSTRINGCHARS][MAXSTRINGCHARLEN + 1]; /* String chars */
-    char stringdups[MAXSTRINGCHARS];		/* No. of "base" char */
-    char dupnos[MAXSTRINGCHARS];		/* Dup char ID # */
+    unsigned int stringdups[MAXSTRINGCHARS];	/* No. of "base" char */
+    int dupnos[MAXSTRINGCHARS];			/* Dup char ID # */
     unsigned short magic2;			/* Second magic for dbl chk */
     };
 
@@ -491,6 +510,7 @@ EXTERN int	co;	/* columns */
 
 EXTERN int	contextsize;	/* number of lines of context to show */
 EXTERN char	contextbufs[MAXCONTEXT][BUFSIZ]; /* Context of current line */
+EXTERN int	contextoffset;	/* Offset of line start in contextbufs[0] */
 EXTERN char *	currentchar;	/* Location in contextbufs */
 EXTERN char	ctoken[INPUTWORDLEN + MAXAFFIXLEN]; /* Current token as char */
 EXTERN ichar_t	itoken[INPUTWORDLEN + MAXAFFIXLEN]; /* Ctoken as ichar_t str */
@@ -518,10 +538,10 @@ EXTERN int	lflag;		/* NZ if -l (list) option */
 EXTERN int	incfileflag;	/* whether xgets() acts exactly like gets() */
 EXTERN int	nodictflag;	/* NZ if dictionary not needed */
 
-EXTERN int	erasechar;	/* User's erase character, from stty */
-EXTERN int	killchar;	/* User's kill character */
+EXTERN int	uerasechar;	/* User's erase character, from stty */
+EXTERN int	ukillchar;	/* User's kill character */
 
-EXTERN int	laststringch;	/* Number of last string character */
+EXTERN unsigned int laststringch; /* Number of last string character */
 EXTERN int	defdupchar;	/* Default duplicate string type */
 
 EXTERN int	numpflags;		/* Number of prefix flags in table */
