@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-	"$Id: makedent.c,v 1.42 1994/02/07 04:23:43 geoff Exp $";
+	"$Id: makedent.c,v 1.44 1994/10/25 05:46:20 geoff Exp $";
 #endif
 
 /*
@@ -43,6 +43,12 @@ static char Rcs_Id[] =
 
 /*
  * $Log: makedent.c,v $
+ * Revision 1.44  1994/10/25  05:46:20  geoff
+ * Fix some incorrect declarations in the lint versions of some routines.
+ *
+ * Revision 1.43  1994/09/16  03:32:34  geoff
+ * Issue an error message for bad affix flags
+ *
  * Revision 1.42  1994/02/07  04:23:43  geoff
  * Correctly identify the deformatter when changing file types
  *
@@ -175,13 +181,11 @@ int makedent (lbuf, lbuflen, d)
     p++;
     while (*p != '\0'  &&  *p != '\n')
 	{
-#if MASKBITS <= 32
-	bit = CHARTOBIT (mytoupper (chartoichar (*p)));
-#else
 	bit = CHARTOBIT ((unsigned char) *p);
-#endif
 	if (bit >= 0  &&  bit <= LARGESTFLAG)
 	    SETMASKBIT (d->mask, bit);
+	else
+	    (void) fprintf (stderr, BAD_FLAG, (unsigned char) *p);
 	p++;
 	if (*p == hashheader.flagmarker)
 	    p++;		/* Handle old-format dictionaries too */
@@ -1068,13 +1072,13 @@ int TSTMASKBIT (mask, bit) MASKTYPE * mask; int bit;
 void CLRMASKBIT (mask, bit) MASKTYPE * mask; int bit; { bit += (int) *mask; }
 void SETMASKBIT (mask, bit) MASKTYPE * mask; int bit; { bit += (int) *mask; }
 int BITTOCHAR (bit) int bit; { return bit; }
-int CHARTOBIT (ch) unsigned int ch; { return ch; }
+int CHARTOBIT (ch) int ch; { return ch; }
 int myupper (ch) unsigned int ch; { return (int) ch; }
 int mylower (ch) unsigned int ch; { return (int) ch; }
 int myspace (ch) unsigned int ch; { return (int) ch; }
 int iswordch (ch) unsigned int ch; { return (int) ch; }
 int isboundarych (ch) unsigned int ch; { return (int) ch; }
-int isstringstart (ch) int ch; { return ch; }
+int isstringstart (ch) unsigned int ch; { return ch; }
 ichar_t mytolower (ch) unsigned int ch; { return (ichar_t) ch; }
 ichar_t mytoupper (ch) unsigned int ch; { return (ichar_t) ch; }
 #endif /* lint */
